@@ -23,16 +23,13 @@
 
 #include <config.h>
 #include <stdlib.h>
-#include <gtk/gtksignal.h>
 #include <libxml/parser.h>
 #include <libxml/xmlmemory.h>
 #include "gal/util/e-xml-utils.h"
 #include "gal/util/e-util.h"
 #include "e-table-column-specification.h"
 
-#define PARENT_TYPE (gtk_object_get_type())
-
-static GtkObjectClass *etcs_parent_class;
+static GObjectClass *etcs_parent_class;
 
 static void
 free_strings (ETableColumnSpecification *etcs)
@@ -50,28 +47,29 @@ free_strings (ETableColumnSpecification *etcs)
 }
 
 static void
-etcs_destroy (GtkObject *object)
+etcs_finalize (GObject *object)
 {
 	ETableColumnSpecification *etcs = E_TABLE_COLUMN_SPECIFICATION (object);
 
 	free_strings(etcs);
 
-	GTK_OBJECT_CLASS (etcs_parent_class)->destroy (object);
+	etcs_parent_class->finalize (object);
 }
 
 static void
-etcs_class_init (GtkObjectClass *klass)
+etcs_class_init (GObjectClass *klass)
 {
-	etcs_parent_class = gtk_type_class (PARENT_TYPE);
+	etcs_parent_class = g_type_class_peek_parent (klass);
 	
-	klass->destroy = etcs_destroy;
+	klass->finalize = etcs_finalize;
 }
 
 static void
 etcs_init (ETableColumnSpecification *specification)
 {
 	specification->model_col     = 0;
-	specification->title        = g_strdup("");
+	specification->compare_col   = 0;
+	specification->title         = g_strdup("");
 	specification->pixbuf        = NULL;
 	
 	specification->expansion     = 0;
@@ -85,12 +83,12 @@ etcs_init (ETableColumnSpecification *specification)
 	specification->priority      = 0;
 }
 
-E_MAKE_TYPE(e_table_column_specification, "ETableColumnSpecification", ETableColumnSpecification, etcs_class_init, etcs_init, PARENT_TYPE)
+E_MAKE_TYPE(e_table_column_specification, "ETableColumnSpecification", ETableColumnSpecification, etcs_class_init, etcs_init, G_TYPE_OBJECT)
 
 ETableColumnSpecification *
 e_table_column_specification_new (void)
 {
-	ETableColumnSpecification *etcs = gtk_type_new (E_TABLE_COLUMN_SPECIFICATION_TYPE);
+	ETableColumnSpecification *etcs = g_object_new (E_TABLE_COLUMN_SPECIFICATION_TYPE, NULL);
 
 	return (ETableColumnSpecification *) etcs;
 }
@@ -101,13 +99,14 @@ e_table_column_specification_load_from_node (ETableColumnSpecification *etcs,
 {
 	free_strings(etcs);
 
-	etcs->model_col     = e_xml_get_integer_prop_by_name(node, "model_col");
-	etcs->title         = e_xml_get_string_prop_by_name(node, "_title");
-	etcs->pixbuf        = e_xml_get_string_prop_by_name(node, "pixbuf");
+	etcs->model_col     = e_xml_get_integer_prop_by_name (node, "model_col");
+	etcs->compare_col   = e_xml_get_integer_prop_by_name_with_default (node, "compare_col", etcs->model_col);
+	etcs->title         = e_xml_get_string_prop_by_name (node, "_title");
+	etcs->pixbuf        = e_xml_get_string_prop_by_name (node, "pixbuf");
 
-	etcs->expansion     = e_xml_get_double_prop_by_name(node, "expansion");
-	etcs->minimum_width = e_xml_get_integer_prop_by_name(node, "minimum_width");
-	etcs->resizable     = e_xml_get_bool_prop_by_name(node, "resizable");
+	etcs->expansion     = e_xml_get_double_prop_by_name (node, "expansion");
+	etcs->minimum_width = e_xml_get_integer_prop_by_name (node, "minimum_width");
+	etcs->resizable     = e_xml_get_bool_prop_by_name (node, "resizable");
 	etcs->disabled      = e_xml_get_bool_prop_by_name (node, "disabled");
 
 	etcs->cell          = e_xml_get_string_prop_by_name (node, "cell");
@@ -130,6 +129,8 @@ e_table_column_specification_save_to_node (ETableColumnSpecification *specificat
 		node = xmlNewNode(NULL, "ETableColumn");
 
 	e_xml_set_integer_prop_by_name(node, "model_col", specification->model_col);
+	if (specification->compare_col != specification->model_col)
+		e_xml_set_integer_prop_by_name(node, "compare_col", specification->compare_col);
 	e_xml_set_string_prop_by_name(node, "_title", specification->title);
 	e_xml_set_string_prop_by_name(node, "pixbuf", specification->pixbuf);
 
