@@ -152,7 +152,7 @@ static void
 dialog_destroyed (gpointer data, GObject *where_object_was)
 {
 	ECategoriesMasterListDialog *ecmld = data;
-	gtk_object_destroy (ecmld);
+	gtk_object_destroy (GTK_OBJECT (ecmld));
 }
 
 static void
